.. Test documentation master file, created by
   sphinxreport-quickstart 

==========
 Contents
==========

Simple tutorial example.

.. report:: Trackers.SimpleExampleData
   :render: interleaved-bar-plot

   Simple example data.

====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


